@@ -1,7 +1,7 @@
 # ABSTRACT: Fix version issues to support all the things
 package App::ElasticSearch::Utilities::VersionHacks;
 
-our $VERSION = '3.4.1'; # VERSION
+our $VERSION = '3.1'; # VERSION
 use strict;
 use warnings;
 
@@ -22,9 +22,6 @@ my %SIMPLE = (
     '_cluster/nodes' => {
         1.0     => '_nodes',
         1.1     => '_nodes',
-        1.2     => '_nodes',
-        1.3     => '_nodes',
-        1.4     => '_nodes',
     }
 );
 my %CALLBACKS = (
@@ -35,9 +32,6 @@ my %CALLBACKS = (
         0.90 => \&_cluster_state_legacy,
         1.0 => \&_cluster_state_1_0,
         1.1 => \&_cluster_state_1_0,
-        1.2 => \&_cluster_state_1_0,
-        1.3 => \&_cluster_state_1_0,
-        1.4 => \&_cluster_state_1_0,
     },
 );
 
@@ -158,15 +152,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 App::ElasticSearch::Utilities::VersionHacks - Fix version issues to support all the things
 
 =head1 VERSION
 
-version 3.4.1
+version 3.1
 
 =head1 AUTHOR
 
